pub struct BatchingHttpTransport { /* private fields */ }Expand description
HTTP transport with batching support
Buffers events and sends them in batches to reduce HTTP overhead. Flushes when either:
- The batch reaches
max_batch_sizeevents - The oldest event in the batch is older than
max_batch_age close()is called (flush remaining events)
Implementations
Sourceimpl BatchingHttpTransport
impl BatchingHttpTransport
pub fn new( base_url: Url, org_id: Uuid, app_id: Uuid, config: BatchConfig, auth_token: Option<String>, ) -> Result<Self, TransportError>
pub fn with_default_config( base_url: Url, org_id: Uuid, app_id: Uuid, auth_token: Option<String>, ) -> Result<Self, TransportError>